@@ -8,6 +8,8 @@
 #
 
 package POE::Component::Server::Time;
+$POE::Component::Server::Time::VERSION = '1.16';
+#ABSTRACT: A POE component that implements an RFC 868 Time server.
 
 use strict;
 use warnings;
@@ -15,13 +17,10 @@ use Carp;
 use POE;
 use Socket;
 use base qw(POE::Component::Server::Echo);
-use vars qw($VERSION);
 
 use constant DATAGRAM_MAXLEN => 1024;
 use constant DEFAULT_PORT => 37;
 
-$VERSION = '1.14';
-
 sub spawn {
   my $package = shift;
   croak "$package requires an even number of parameters" if @_ & 1;
@@ -89,13 +88,22 @@ sub _get_datagram {
   undef;
 }
 
-1;
+qq[Mind is perpetual motion. Its symbol is the sphere.];
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 POE::Component::Server::Time - A POE component that implements an RFC 868 Time server.
 
+=head1 VERSION
+
+version 1.16
+
 =head1 SYNOPSIS
 
  use POE::Component::Server::Time;
@@ -118,7 +126,7 @@ L<POE>. It is a class inherited from L<POE::Component::Server::Echo>.
 
 =item C<spawn>
 
-Takes a number of optional values: 
+Takes a number of optional values:
 
   "Alias", the kernel alias that this component is to be blessed with; 
   "BindAddress", the address on the local host to bind to, defaults to 
@@ -134,16 +142,6 @@ Takes a number of optional values:
 
 Report any bugs through L<http://rt.cpan.org/>.
 
-=head1 AUTHOR
-
-Chris 'BinGOs' Williams, <chris@bingosnet.co.uk>
-
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<POE>
@@ -156,4 +154,15 @@ L<POE::Component::Server::Echo>
 
 L<http://www.faqs.org/rfcs/rfc868.html>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
